@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/i386/seamonkey-1.1.18p1/mozilla/xpfe/global/../../toolkit/content/inlineSpellCheckUI.js"
+//@line 38 "/usr/obj/ports/seamonkey-2.0.6/comm-1.9.1/mozilla/toolkit/content/inlineSpellCheckUI.js"
 
 var InlineSpellCheckerUI = {
   mOverMisspelling: false,
@@ -18,7 +18,7 @@ var InlineSpellCheckerUI = {
     this.uninit();
     this.mEditor = aEditor;
     try {
-      this.mInlineSpellChecker = this.mEditor.inlineSpellChecker;
+      this.mInlineSpellChecker = this.mEditor.getInlineSpellChecker(true);
       // note: this might have been NULL if there is no chance we can spellcheck
     } catch(e) {
       this.mInlineSpellChecker = null;
@@ -45,7 +45,7 @@ var InlineSpellCheckerUI = {
   {
     this.mOverMisspelling = false;
 
-    if (! this.mInlineSpellChecker)
+    if (!rangeParent || !this.mInlineSpellChecker)
       return;
 
     var selcon = this.mEditor.selectionController;
@@ -82,7 +82,7 @@ var InlineSpellCheckerUI = {
   set enabled(isEnabled)
   {
     if (this.mInlineSpellChecker)
-      this.mEditor.QueryInterface(Components.interfaces.nsIEditor_MOZILLA_1_8_BRANCH).setSpellcheckUserOverride(isEnabled);
+      this.mEditor.setSpellcheckUserOverride(isEnabled);
   },
 
   // returns true if the given event is over a misspelled word
@@ -165,7 +165,7 @@ var InlineSpellCheckerUI = {
 
     for (var i = 0; i < list.length; i ++) {
       // get the display name for this dictionary
-      isoStrArray = list[i].split("-");
+      isoStrArray = list[i].split(/[-_]/);
       var displayName = "";
       if (this.mLanguageBundle && isoStrArray[0]) {
         try {
@@ -186,6 +186,7 @@ var InlineSpellCheckerUI = {
 
       this.mDictionaryNames.push(list[i]);
       var item = document.createElement("menuitem");
+      item.setAttribute("id", "spell-check-dictionary-" + list[i]);
       item.setAttribute("label", displayName);
       item.setAttribute("type", "checkbox");
       this.mDictionaryItems.push(item);
@@ -219,7 +220,6 @@ var InlineSpellCheckerUI = {
     if (! this.mInlineSpellChecker || index < 0 || index >= this.mDictionaryNames.length)
       return;
     var spellchecker = this.mInlineSpellChecker.spellChecker;
-    spellchecker.QueryInterface(Components.interfaces.nsIEditorSpellCheck_MOZILLA_1_8_BRANCH);
     spellchecker.SetCurrentDictionary(this.mDictionaryNames[index]);
     spellchecker.saveDefaultDictionary();
     this.mInlineSpellChecker.spellCheckRange(null); // causes recheck
@@ -239,12 +239,16 @@ var InlineSpellCheckerUI = {
   // callback for enabling or disabling spellchecking
   toggleEnabled: function()
   {
-    this.mEditor.QueryInterface(Components.interfaces.nsIEditor_MOZILLA_1_8_BRANCH).setSpellcheckUserOverride(!this.mInlineSpellChecker.enableRealTimeSpell);
+    this.mEditor.setSpellcheckUserOverride(!this.mInlineSpellChecker.enableRealTimeSpell);
   },
 
   // callback for adding the current misspelling to the user-defined dictionary
   addToDictionary: function()
   {
     this.mInlineSpellChecker.addWordToDictionary(this.mMisspelling);
+  },
+  ignoreWord: function()
+  {
+    this.mInlineSpellChecker.ignoreWord(this.mMisspelling);
   }
 };
